@@ -1,11 +1,11 @@
-from typing_extensions import TypeVar, overload
+from typing_extensions import TypeVar, Any
 from urllib.parse import urlparse, parse_qs, unquote
 from pydantic import BaseModel
 from kv import KV
 
 T = TypeVar('T')
 
-def parse_type(type: str):
+def parse_type(type: str) -> type:
   if type == 'dict':
     return dict
   if type == 'list':
@@ -21,15 +21,17 @@ def parse_type(type: str):
   if type == 'bool':
     return bool
   if type == 'bytes':
-    return None
+    return bytes
+  if type == 'any':
+    return Any # type: ignore
   raise ValueError(f'Invalid type: {type}')
 
 class Params(BaseModel):
   prefix: str | None = None
-  type: str | None = None
+  type: str = 'any'
 
 class HTTPParams(Params):
-  token: str | None = None
+  secret: str | None = None
 
 class AzureBlobParams(Params):
   container: str | None = None
@@ -42,13 +44,7 @@ class CosmosParams(Params):
 class SQLParams(Params):
   table: str
 
-@overload
-def parse(conn_str: str) -> KV[bytes]:
-  ...
-@overload
-def parse(conn_str: str, type: type[T] | None = None) -> KV[T]:
-  ...
-def parse(conn_str: str, type: type[T] | None = None): # type: ignore
+def parse(conn_str: str, type: type[T]) -> KV[T]:
   parsed_url = urlparse(conn_str) # 'file://path/to/base?prefix=hello'
   scheme = parsed_url.scheme # 'file'
   netloc = parsed_url.netloc # 'path'
@@ -58,17 +54,17 @@ def parse(conn_str: str, type: type[T] | None = None): # type: ignore
   query = { k: v[0] for k, v in query.items() }
 
   params = Params(**query)
-  type = type or params.type and parse_type(params.type) # type: ignore
+  type = type or parse_type(params.type)
 
   if scheme in ('http', 'https'):
     params = HTTPParams(**query)
-    from kv.http import ClientKV
+    from kv import ClientKV
     url = f'{scheme}://{endpoint}'
-    kv = ClientKV.new(url, type, token=params.token)
+    kv = ClientKV.new(url, type, secret=params.secret)
 
   elif scheme == 'azure+blob':
     params = AzureBlobParams(**query)
-    from kv.azure import BlobKV, BlobContainerKV
+    from kv import BlobKV, BlobContainerKV
     if params.container:
       kv = BlobContainerKV.from_conn_str(endpoint, params.container, type)
     else:
@@ -76,7 +72,7 @@ def parse(conn_str: str, type: type[T] | None = None): # type: ignore
 
   elif scheme == 'azure+cosmos':
     params = CosmosParams(**query)
-    from kv.azure import CosmosKV, CosmosContainerKV, CosmosPartitionKV
+    from kv import CosmosKV, CosmosContainerKV, CosmosPartitionKV
     if params.container and params.partition:
       kv = CosmosPartitionKV.from_conn_str(endpoint, type, db=params.db, container=params.container, partition_key=params.partition)
     elif params.container:
@@ -84,11 +80,6 @@ def parse(conn_str: str, type: type[T] | None = None): # type: ignore
     else:
       kv = CosmosKV.from_conn_str(endpoint, type, db=params.db)
 
-  elif scheme == 'sqlite':
-    params = SQLParams(**query)
-    from kv import SQLiteKV
-    kv = SQLiteKV.at(endpoint, type, table=params.table)
-
   elif scheme.startswith('sql+'):
     params = SQLParams(**query)
     from kv import SQLKV
@@ -110,4 +101,4 @@ def parse(conn_str: str, type: type[T] | None = None): # type: ignore
   else:
     raise ValueError(f'Unknown scheme: {scheme}')
   
-  return kv.prefixed(params.prefix) if params.prefix else kv
\ No newline at end of file
+  return kv.prefixed(params.prefix) if params.prefix else kv # type: ignore
\ No newline at end of file
